==> nezha-compute-api-1.0.24-20170613.074336-1-sources.jar: cn/com/duiba/nezha/compute/api/dto/AdvertAppStatDto.java <==
package cn.com.duiba.nezha.compute.api.dto;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;

/**
 * Created by pc on 2016/11/16.
 */
public class AdvertAppStatDto implements Serializable {

    private static final long serialVersionUID = -316102112618444133L;

    private String key;

    private Long appId;
    private Long advertId;

    private AdvertCtrStatDto globalCdStat; // 广告全局维度,首次投放,当日 CTR
    private AdvertCtrStatDto globalCdRepeatStat; // 广告全局维度,重复投放,当日 CTR
    private AdvertCtrStatDto appCdStat;// 广告媒体维度,首次投放,当日 CTR
    private AdvertCtrStatDto appCdRepeatStat;// 广告媒体维度,重复投放,当日 CTR


    private AdvertCtrStatDto globalR7dStat; // 广告全局维度,首次投放,近7日CTR
    private AdvertCtrStatDto globalR7dRepeatStat; // 广告全局维度,重复投放,近7日CTR
    private AdvertCtrStatDto appR7dStat;// 广告媒体维度,首次投放,近7日CTR
    private AdvertCtrStatDto appR7dRepeatStat;// 广告媒体维度,重复投放,近7日CTR

    public String getKey() {return key;}

    public void setKey(String key) {this.key = key;}


    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }


    public AdvertCtrStatDto getGlobalCdStat() {
        return globalCdStat;
    }

    public void setGlobalCdStat(AdvertCtrStatDto globalCdStat) {
        this.globalCdStat = globalCdStat;
    }

    public AdvertCtrStatDto getGlobalCdRepeatStat() {
        return globalCdRepeatStat;
    }

    public void setGlobalCdRepeatStat(AdvertCtrStatDto globalCdRepeatStat) {
        this.globalCdRepeatStat = globalCdRepeatStat;
    }

    public AdvertCtrStatDto getAppCdStat() {
        return appCdStat;
    }

    public void setAppCdStat(AdvertCtrStatDto appCdStat) {
        this.appCdStat = appCdStat;
    }

    public AdvertCtrStatDto getAppCdRepeatStat() {
        return appCdRepeatStat;
    }

    public void setAppCdRepeatStat(AdvertCtrStatDto appCdRepeatStat) {
        this.appCdRepeatStat = appCdRepeatStat;
    }






    public AdvertCtrStatDto getGlobalR7dStat() {
        return globalR7dStat;
    }

    public void setGlobalR7dStat(AdvertCtrStatDto globalR7dStat) {
        this.globalR7dStat = globalR7dStat;
    }

    public AdvertCtrStatDto getGlobalR7dRepeatStat() {
        return globalR7dRepeatStat;
    }

    public void setGlobalR7dRepeatStat(AdvertCtrStatDto globalR7dRepeatStat) {
        this.globalR7dRepeatStat = globalR7dRepeatStat;
    }

    public AdvertCtrStatDto getAppR7dStat() {
        return appR7dStat;
    }

    public void setAppR7dStat(AdvertCtrStatDto appR7dStat) {
        this.appR7dStat = appR7dStat;
    }

    public AdvertCtrStatDto getAppR7dRepeatStat() {
        return appR7dRepeatStat;
    }

    public void setAppR7dRepeatStat(AdvertCtrStatDto appR7dRepeatStat) {
        this.appR7dRepeatStat = appR7dRepeatStat;
    }



}

==> nezha-compute-api-1.0.39-20170724.040011-2-sources.jar: cn/com/duiba/nezha/compute/api/dto/AdvertAppStatDto.java <==
package cn.com.duiba.nezha.compute.api.dto;

import java.io.Serializable;

/**
 * Created by pc on 2016/11/16.
 */
public class AdvertAppStatDto implements Serializable {

    private static final long serialVersionUID = -316102112618444133L;

    private String key;

    private Long appId;
    private Long advertId;

    private Long materialId;


    private AdvertCtrStatDto globalCdStat; // 广告全局维度,首次投放,当日 CTR
    private AdvertCtrStatDto globalCdRepeatStat; // 广告全局维度,重复投放,当日 CTR
    private AdvertCtrStatDto appCdStat;// 广告媒体维度,首次投放,当日 CTR
    private AdvertCtrStatDto appCdRepeatStat;// 广告媒体维度,重复投放,当日 CTR

    private AdvertCtrStatDto appChStat;// 广告媒体维度,首次投放,当小时 CTR
    private AdvertCtrStatDto appChRepeatStat;// 广告媒体维度,重复投放,当小时 CTR

    private AdvertCtrStatDto appR2hStat;// 广告媒体维度,首次投放,近2小时CTR
    private AdvertCtrStatDto appR2hRepeatStat;// 广告媒体维度,重复投放,近2小时CTR


    private AdvertCtrStatDto globalR7dStat; // 广告全局维度,首次投放,近7日CTR
    private AdvertCtrStatDto globalR7dRepeatStat; // 广告全局维度,重复投放,近7日CTR
    private AdvertCtrStatDto appR7dStat;// 广告媒体维度,首次投放,近7日CTR
    private AdvertCtrStatDto appR7dRepeatStat;// 广告媒体维度,重复投放,近7日CTR

    public String getKey() {return key;}

    public void setKey(String key) {this.key = key;}


    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }



    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }


    public AdvertCtrStatDto getGlobalCdStat() {
        return globalCdStat;
    }

    public void setGlobalCdStat(AdvertCtrStatDto globalCdStat) {
        this.globalCdStat = globalCdStat;
    }

    public AdvertCtrStatDto getGlobalCdRepeatStat() {
        return globalCdRepeatStat;
    }

    public void setGlobalCdRepeatStat(AdvertCtrStatDto globalCdRepeatStat) {
        this.globalCdRepeatStat = globalCdRepeatStat;
    }

    public AdvertCtrStatDto getAppCdStat() {
        return appCdStat;
    }

    public void setAppCdStat(AdvertCtrStatDto appCdStat) {
        this.appCdStat = appCdStat;
    }

    public AdvertCtrStatDto getAppCdRepeatStat() {
        return appCdRepeatStat;
    }

    public void setAppCdRepeatStat(AdvertCtrStatDto appCdRepeatStat) {
        this.appCdRepeatStat = appCdRepeatStat;
    }


    public AdvertCtrStatDto getAppChStat() {
        return appChStat;
    }

    public void setAppChStat(AdvertCtrStatDto appChStat) {
        this.appChStat = appChStat;
    }

    public AdvertCtrStatDto getAppChRepeatStat() {
        return appChRepeatStat;
    }

    public void setAppChRepeatStat(AdvertCtrStatDto appChRepeatStat) {
        this.appChRepeatStat = appChRepeatStat;
    }



    public AdvertCtrStatDto getAppR2hStat() {
        return appR2hStat;
    }

    public void setAppR2hStat(AdvertCtrStatDto appR2hStat) {
        this.appR2hStat = appR2hStat;
    }

    public AdvertCtrStatDto getAppR2hRepeatStat() {
        return appR2hRepeatStat;
    }

    public void setAppR2hRepeatStat(AdvertCtrStatDto appR2hRepeatStat) {
        this.appR2hRepeatStat = appR2hRepeatStat;
    }






    public AdvertCtrStatDto getGlobalR7dStat() {
        return globalR7dStat;
    }

    public void setGlobalR7dStat(AdvertCtrStatDto globalR7dStat) {
        this.globalR7dStat = globalR7dStat;
    }

    public AdvertCtrStatDto getGlobalR7dRepeatStat() {
        return globalR7dRepeatStat;
    }

    public void setGlobalR7dRepeatStat(AdvertCtrStatDto globalR7dRepeatStat) {
        this.globalR7dRepeatStat = globalR7dRepeatStat;
    }

    public AdvertCtrStatDto getAppR7dStat() {
        return appR7dStat;
    }

    public void setAppR7dStat(AdvertCtrStatDto appR7dStat) {
        this.appR7dStat = appR7dStat;
    }

    public AdvertCtrStatDto getAppR7dRepeatStat() {
        return appR7dRepeatStat;
    }

    public void setAppR7dRepeatStat(AdvertCtrStatDto appR7dRepeatStat) {
        this.appR7dRepeatStat = appR7dRepeatStat;
    }



}
